{% extends "zinnia:zinnia/author_list.html" %}
{% load i18n %}

{% block content %}
<h1>{% trans "Author list" %}</h1>

<ul class="list-group">
  {% for object in object_list %}
  <li class="vcard list-group-item">
    <a href="{{ object.get_absolute_url }}"
       title="{% blocktrans with author=object %}Show all {{ author }}'s entries{% endblocktrans %}"
       class="fn url{% if not author.get_full_name %} nickname{% endif %}">{{ object }}</a>
    <span class="badge">
      {% blocktrans count entry_count=object.count_entries_published %}{{ entry_count }} entry{% plural %}{{ entry_count }} entries{% endblocktrans %}
    </span>
  </li>
  {% empty %}
  <li>
    {% trans "No authors yet." %}
  </li>
  {% endfor %}
</ul>
{% endblock content %}
