{% load i18n staticfiles %}
<!doctype html>
<html lang="{{ LANGUAGE_CODE }}">
  <head>
    <meta charset="utf-8">
    <title>Zinnia's Weblog - {% block title %}{% endblock title %}{% block title-page %}{% endblock title-page %}</title>
    <meta name="robots" content="follow, all" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta name="description" content="{% block meta-description %}{% trans "Just another Zinnia weblog." %}{% endblock meta-description %}{% block meta-description-page %}{% endblock meta-description-page %}" />
    <meta name="keywords" content="{% block meta-keywords %}django, blog, weblog, zinnia{% endblock meta-keywords %}" />
    <meta name="author" content="Fantomas42" />
    {% block meta %}{% endblock meta %}
    <link rel="pingback" href="/xmlrpc/" />
    <link rel="home" href="{% url 'zinnia:entry_archive_index' %}" />
    <link rel="stylesheet" href="{% static "zinnia_bootstrap/bootstrap/css/bootstrap.min.css" %}" />
    <style type="text/css">
      body {
        padding-top: 70px;
      }
      body > nav img {
        margin-top: 5px;
        margin-left: 10px;
      }
      p.entry-discussions {
        margin-bottom: 0px;
      }
    </style>
    <!--[if lt IE 9]>
        <script src="{% static "zinnia_bootstrap/assets/js/html5shiv.js" %}"></script>
        <script src="{% static "zinnia_bootstrap/assets/js/respond.min.js" %}"></script>
    <![endif]-->
    <link rel="shortcut icon" href="{% static "zinnia/theme/img/favicon.ico" %}" />
    <link rel="apple-touch-icon-precomposed" sizes="144x144" href="{% static "zinnia_bootstrap/assets/ico/apple-touch-icon-144-precomposed.png" %}" />
    <link rel="apple-touch-icon-precomposed" sizes="114x114" href="{% static "zinnia_bootstrap/assets/ico/apple-touch-icon-114-precomposed.png" %}" />
    <link rel="apple-touch-icon-precomposed" sizes="72x72" href="{% static "zinnia_bootstrap/assets/ico/apple-touch-icon-72-precomposed.png" %}" />
    <link rel="apple-touch-icon-precomposed" href="{% static "zinnia_bootstrap/assets/ico/apple-touch-icon-57-precomposed.png" %}" />
    {% block link %}{% endblock link %}
    {% block script %}{% endblock script %}
  </head>
  <body class="zinnia {% block body-class %}{% endblock body-class %}">
    <nav class="navbar navbar-default navbar-fixed-top navbar-inverse" role="navigation">
      <div class="container">
        <div class="navbar-header">
          <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
            <span class="sr-only">{% trans "Toggle navigation" %}</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <img src="{% static "zinnia_bootstrap/img/zinnia.png" %}" class="pull-left" alt="Zinnia's Weblog" />
          <a href="{% url 'zinnia:entry_archive_index' %}" title="Zinnia's Welog" class="navbar-brand" rel="home">
            Zinnia's Weblog
          </a>
        </div>
        <div class="collapse navbar-collapse navbar-ex1-collapse">
          <ul class="nav navbar-nav navbar-left">
            {% url 'zinnia:category_list' as category_list_url %}
            <li {% if category_list_url in request.path %}class="active"{% endif %}>
              <a href="{{ category_list_url }}" title="{% trans "Category list" %}">
                {% trans "Categories" %}
              </a>
            </li>
            {% url 'zinnia:author_list' as author_list_url %}
            <li {% if author_list_url in request.path %}class="active"{% endif %}>
              <a href="{{ author_list_url }}" title="{% trans "Author list" %}">
                {% trans "Authors" %}
              </a>
            </li>
            {% url 'zinnia:tag_list' as tag_list_url %}
            <li {% if tag_list_url in request.path %}class="active"{% endif %}>
              <a href="{{ tag_list_url }}" title="{% trans "Tag list" %}">
                {% trans "Tags" %}
              </a>
            </li>
            <li class="divider-vertical"></li>
          </ul>
          <form method="get" action="{% url 'zinnia:entry_search' %}" class="navbar-form navbar-left">
            <div class="form-group">
              <input type="text" class="search-query form-control" placeholder="{% trans 'Search' %}" name="pattern" value="{{ pattern }}" />
            </div>
            <button type="submit" name="submit" class="btn btn-default btn-sm">
              <span class="glyphicon glyphicon-search"></span>
            </button>
          </form>
          <ul class="nav navbar-nav navbar-right">
            {% url 'zinnia:sitemap' as sitemap_url %}
            <li {% if sitemap in request.path %}class="active"{% endif %}>
            <li>
              <a href="{{ sitemap_url }}" title="{% trans "Sitemap" %}" class="sitemap">
                {% trans "Sitemap" %}
              </a>
            </li>
            <li class="divider-vertical"></li>
            <li>
              <a href="{% url 'zinnia:entry_feed' %}" title="{% trans "RSS Feed of latest entries" %}" class="feeds">
                {% trans "RSS Feed" %}
              </a>
            </li>
          </ul>
        </div>
      </div>
    </nav>
    {% block slider %}{% endblock %}
    <div class="container">
      <div class="row">
        <div id="content" class="hfeed col-xs-12 col-sm-8 col-md-8 col-lg-8">
          {% block breadcrumbs %}{% endblock %}
          {% block content %}
          <div class="links">
            <h3>{% trans "Useful links" %}</h3>
            <ul>
              <li>
                <a href="{% url 'zinnia:entry_archive_index' %}" title="{% trans "Weblog index" %}">
                  {% trans "Weblog index" %}
                </a>
              </li>
              <li>
                <a href="{% url 'zinnia:sitemap' %}" title="{% trans "Sitemap" %}">
                  {% trans "Sitemap" %}
                </a>
              </li>
            </ul>
          </div>
          <div class="search">
            <h3>{% trans "Search" %}</h3>
            {% include "zinnia/tags/search_form.html" %}
          </div>
          {% endblock content %}
        </div>
        <div id="sidebar" class="col-xs-12 col-sm-4 col-md-4 col-lg-4">
          {% block sidebar %}
          {% endblock sidebar %}
        </div>
      </div>
    </div>
    <footer class="container">
      <p>{% blocktrans %}Powered by <a href="http://www.djangoproject.com">Django</a> and <a href="https://github.com/Fantomas42/django-blog-zinnia">Zinnia {{ ZINNIA_VERSION }}</a>.{% endblocktrans %}</p>
    </footer>
    <script type="text/javascript" src="{% static "zinnia_bootstrap/assets/js/jquery.js" %}"></script>
    <script type="text/javascript" src="{% static "zinnia_bootstrap/bootstrap/js/bootstrap.min.js" %}"></script>
  </body>
</html>
