<ul class="breadcrumb">
  {% for crumb in breadcrumbs %}
  <li {% if forloop.last %}class="active"{% endif%}>
    {% if crumb.url %}
    <a href="{{ crumb.url }}" title="{{ crumb.name }}">{{ crumb.name }}</a>
    {% else %}
    {{ crumb.name }}
    {% endif %}
  </li>
  {% endfor %}
</ul>
