{% load i18n %}
<ul class="list-group {% if not authors %}no-{% endif %}authors">
  {% for author in authors %}
  <li class="vcard list-group-item{% if author.get_username == context_author.get_username %} current{% endif %}">
    <a href="{{ author.get_absolute_url }}"
       title="{% blocktrans %}Show all {{ author }}'s entries{% endblocktrans %}"
       class="fn url{% if not author.get_full_name %} nickname{% endif %}">{{ author }}
      <span class="label label-info">
        {% blocktrans count entry_count=author.count_entries_published %}{{ entry_count }} entry{% plural %}{{ entry_count }} entries{% endblocktrans %}
      </span>
    </a>
  </li>
  {% empty %}
  <li class="list-group-item">
    {% trans "No authors yet." %}
  </li>
  {% endfor %}
</ul>
