{% extends "zinnia:zinnia/base.html" %}
{% load zinnia i18n %}

{% block sidebar %}
<aside id="widget-welcome" class="widget panel panel-default">
  <div class="panel-heading">
    {% trans "Welcome!" %}
  </div>
  <div class="panel-body">
    <p>
      {% trans "This simple theme is the default appearance of Zinnia." %}
    </p>
    <p>
      {% trans "Don't hesitate to override the template <strong>zinnia/base.html</strong> to start <a href='http://docs.django-blog-zinnia.com/en/latest/how-to/customize_look_and_feel.html'>customizing your Weblog</a>." %}
    </p>
  </div>
</aside>
<aside id="widget-categories" class="widget panel panel-default">
  <div class="panel-heading">
    {% trans "Categories" %}
  </div>
  {% get_categories %}
</aside>
<aside id="widget-authors" class="widget panel panel-default">
  <div class="panel-heading">
    {% trans "Authors" %}
  </div>
  {% get_authors %}
</aside>
<aside id="widget-recents" class="widget panel panel-default">
  <div class="panel-heading">
    {% trans "Recent entries" %}
  </div>
  {% get_recent_entries %}
</aside>
<aside id="widget-comments" class="widget panel panel-default">
  <div class="panel-heading">
    {% trans "Recent comments" %}
  </div>
  {% get_recent_comments %}
</aside>
<aside id="widget-linkbacks" class="widget panel panel-default">
  <div class="panel-heading">
    {% trans "Recent linkbacks" %}
  </div>
  {% get_recent_linkbacks %}
</aside>
<aside id="widget-randoms" class="widget panel panel-default">
  <div class="panel-heading">
    {% trans "Random entries" %}
  </div>
  {% get_random_entries %}
</aside>
<aside id="widget-populars" class="widget panel panel-default">
  <div class="panel-heading">
    {% trans "Popular entries" %}
  </div>
  {% get_popular_entries %}
</aside>
{% if user.is_authenticated %}
<aside id="widget-tools" class="widget panel panel-danger">
  <div class="panel-heading">
    {% trans "Tools" %}
  </div>
  <ul class="list-group">
    {% if perms.zinnia %}
    <li class="list-group-item">
      <a href="{% url 'admin:app_list' 'zinnia' %}" title="{% trans "Dashboard" %}">
        <span class="glyphicon glyphicon-book"></span>
        {% trans "Dashboard" %}
      </a>
    </li>
    {% endif %}
    {% if perms.zinnia.add_entry %}
    <li class="list-group-item">
      <a href="{% url 'admin:zinnia_entry_add' %}" title="{% trans "Post an entry" %}">
        <span class="glyphicon glyphicon-pencil"></span>
        {% trans "Post an entry" %}
      </a>
    </li>
    {% endif %}
    {% block admin-tools %}
    {% endblock admin-tools %}
    <li class="list-group-item">
      <a href="{% url 'admin:logout' %}" title="{% trans "Log out" %}">
        <span class="glyphicon glyphicon-off"></span>
        {% trans "Log out" %}
      </a>
    </li>
  </ul>
</aside>
{% endif %}
{% endblock sidebar %}
