{% extends "zinnia:zinnia/tag_list.html" %}
{% load i18n %}

{% block content %}
<h1>{% trans "Tag list" %}</h1>

<ul class="list-group">
  {% for object in object_list %}
  <li class="list-group-item">
    <a href="{% url 'zinnia:tag_detail' object %}"
       title="{% blocktrans with tag=object %}Show all entries tagged by {{ tag }}{% endblocktrans %}">{{ object }}</a>
    <span class="badge">
      {% blocktrans count entry_count=object.count %}{{ entry_count }} entry{% plural %}{{ entry_count }} entries{% endblocktrans %}
    </span>
  </li>
  {% empty %}
  <li>
    {% trans "No tags yet." %}
  </li>
  {% endfor %}
</ul>
{% endblock content %}
